%--------------------------------------------------------------------------
%------- Main code Chapter 3: Econometrics of Returns  ------
%--------------------------------------------------------------------------
%
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%------- Housekeeping and Load Data-----------------------------------------------------
%--------------------------------------------------------------------------
close all; clear all; clc; pause(0.01), randn('seed',sum(clock)), rand('seed',sum(clock)), warning off

addpath([pwd '\Input\']);
addpath([pwd '\Utilities\']);
addpath([pwd '\Output\']);
% Load data
[data,textdata,raw] = xlsread('FF_Data_CH3.xls','Data');

%% Label Data and Transform 
R_MKT  = (data(:,2)+data(:,5))*0.01;
R_SMB=data(:,3)*0.01;
R_HML=data(:,4)*0.01;
R_RF=data(:,5)*0.01;
R_MOM=data(:,6)*0.01;
R_PR11=data(:,7)*0.01;
R_PR12=data(:,8)*0.01;
R_PR13=data(:,9)*0.01;
R_PR14=data(:,10)*0.01;
R_PR15=data(:,11)*0.01;
R_PR21=data(:,12)*0.01;
R_PR22=data(:,13)*0.01;
R_PR23=data(:,14)*0.01;
R_PR24=data(:,15)*0.01;
R_PR25=data(:,16)*0.01;
R_PR31=data(:,17)*0.01;	
R_PR32=data(:,18)*0.01;
R_PR33=data(:,19)*0.01;
R_PR34=data(:,20)*0.01;
R_PR35=data(:,21)*0.01;
R_PR41=data(:,22)*0.01;
R_PR42=data(:,23)*0.01;	
R_PR43=data(:,24)*0.01;	
R_PR44=data(:,25)*0.01;
R_PR45=data(:,26)*0.01;
R_PR51=data(:,27)*0.01;
R_PR52=data(:,28)*0.01;
R_PR53=data(:,29)*0.01;
R_PR54=data(:,30)*0.01;
R_PR55=data(:,31)*0.01;
ER_15=(R_PR15-R_RF);
ER_51=(R_PR51-R_RF);
ER_MKT=(R_MKT-R_RF);
R_PR15_A=NaN(size(R_PR15));
R_PR51_A=NaN(size(R_PR15));
R_MKT_A=NaN(size(R_PR15));
R_RF_A=NaN(size(R_PR15));
t = [1:size(R_PR15)];
for i=12:size(t,2)
R_PR15_A(i,:) = prod(1+R_PR15(t(i)-11:t(i)))-1;
R_PR51_A(i,:) = prod(1+R_PR51(t(i)-11:t(i)))-1;
R_MKT_A(i,:) = prod(1+R_MKT(t(i)-11:t(i)))-1;
R_RF_A(i,:) = prod(1+R_RF(t(i)-11:t(i)))-1;
end
ER_15_A=(R_PR15_A-R_RF_A);
ER_51_A=(R_PR51_A-R_RF_A);
ER_MKT_A=(R_MKT_A-R_RF_A);
%% compute annual decimated data
ER_MKT_AA(1,:)=ER_MKT_A(6,:);
for i=1:((size(t,2)-6)/12)
ER_MKT_AA(1+i,:)=R_MKT_A(6+12*i,:);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Preliminary Data Analysis 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
date=datenum(textdata(2:end,1),'dd/mm/yyyy');%Convert dates into a serial number
s_start1 = '15/01/1962';
s_end1   = '15/06/2014';
date_find1=datenum([s_start1; s_end1],'dd/mm/yyyy'); % Lookup row number
ss1=datefind(date_find1(1,1),date); % Sample Start (First Raw)
se1=datefind(date_find1(2,1),date); % Sample End (Last Raw)
ObsSample = se1-ss1+1; % Number of observations within Sample
%% Analyzing Returns and Historical Performance 
Port_mkt=NaN(size(R_PR15));
Port_15=NaN(size(R_PR15));
Port_51=NaN(size(R_PR15));
Port_rf=NaN(size(R_PR15));
Port_smb=NaN(size(R_PR15));
Port_hml=NaN(size(R_PR15));
Port_mom=NaN(size(R_PR15));
Port_mkt(ss1,1)=1;
Port_15(ss1,1)=1;
Port_51(ss1,1)=1;
Port_rf(ss1,1)=1;
Port_smb(ss1,1)=1;
Port_hml(ss1,1)=1;
Port_mom(ss1,1)=1;

for i=ss1+1:se1
 Port_mkt(i,1)=Port_mkt(i-1,1)*(1+R_MKT(i,1));  
 Port_rf(i,1)=Port_rf(i-1,1)*(1+R_RF(i,1));
 Port_15(i,1)=Port_15(i-1,1)*(1+R_PR15(i,1));
 Port_51(i,1)=Port_51(i-1,1)*(1+R_PR51(i,1));
 Port_smb(i,1)=Port_smb(i-1,1)*(1+R_SMB(i,1));
 Port_hml(i,1)=Port_hml(i-1,1)*(1+R_HML(i,1));
 Port_mom(i,1)=Port_mom(i-1,1)*(1+R_MOM(i,1));
 end
Port = [Port_mkt(ss1:se1) Port_rf(ss1:se1) Port_51(ss1:se1)];
% Plot performances  in figure(1)
run Figure001   
% plot of returns 
run Figure002
run Figure003
run Figure004

EXRET=[ER_MKT(ss1:se1) ER_15(ss1:se1) ER_51(ss1:se1)];
stats = [(mean(EXRET))' (std(EXRET))' (skewness(EXRET))' (kurtosis(EXRET))'];
xlswrite('Output/Tables.xlsx',stats,'Table1','C3:F5');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Interpreting Regression Results 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
run ch3_section2

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% CAPM and Misspecification Analysis  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
run ch3_section3

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fama McBeth  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

